@@ -106,6 +106,22 @@ abstract class Unit_Math_BigInteger_TestCase extends PhpseclibTestCase
 
         $this->assertSame('95627922070', (string) $q);
         $this->assertSame('10688759725', (string) $r);
+
+        $x = $this->getInstance('3369993333393829974333376885877453834204643052817571560137951281152');
+        $y = $this->getInstance('4294967296');
+
+        list($q, $r) = $x->divide($y);
+
+        $this->assertSame('784637716923335095479473677900958302012794430558004314112', (string) $q);
+        $this->assertSame('0', (string) $r);
+
+        $x = $this->getInstance('3369993333393829974333376885877453834204643052817571560137951281153');
+        $y = $this->getInstance('4294967296');
+
+        list($q, $r) = $x->divide($y);
+
+        $this->assertSame('784637716923335095479473677900958302012794430558004314112', (string) $q);
+        $this->assertSame('1', (string) $r);
     }
 
     public function testModPow()
@@ -418,4 +434,21 @@ abstract class Unit_Math_BigInteger_TestCase extends PhpseclibTestCase
         $temp = $this->getInstance('-0');
         $this->assertSame($temp->toString(), '0');
     }
+
+    public function testNegativePrecision()
+    {
+        $vals = [
+            '-9223372036854775808', // eg. 8000 0000 0000 0000
+            '-1'
+        ];
+        foreach ($vals as $val) {
+            $x = $this->getInstance($val);
+            $x->setPrecision(64); // ie. 8 bytes
+            $this->assertSame($val, "$x");
+            $r = $x->toBytes(true);
+            $this->assertSame(8, strlen($r));
+            $x2 = $this->getInstance($r, -256);
+            $this->assertSame(0, $x->compare($x2));
+        }
+    }
 }
